@@ -7,10 +7,10 @@ class PriorBalance private () extends Prior {
   private val logC = math.log(0.4332)
 
   def apply(state: Bamboo): Double = {
-    (state.ssBlocks :+ (" ",0), (" ",0) +: state.ssBlocks).zipped.foreach( (x,y) => {
+    (state.ssBlocks :+ (" ",0)).zip((" ",0) +: state.ssBlocks).foreach { case (x,y) =>
       if ( ( x._1 == "H" ) && ( y._1 == "E" ) ) return Double.NegativeInfinity
       if ( ( x._1 == "E" ) && ( y._1 == "H" ) ) return Double.NegativeInfinity
-    })
+    }
     val sequence = state.asSequence
     sequence.map( _ match {
       case "H" => logH
